nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Dma0ReqEnable0Tog

Struct Dma0ReqEnable0Tog 

#[repr(transparent)]
pub struct Dma0ReqEnable0Tog(pub u32);
DMA0 Request Enable0

Tuple Fields

0: u32

Implementations

Source

impl Dma0ReqEnable0Tog

pub const fn req1_en0(&self) -> bool

Writing a 1 to REQ1_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req1_en0(&mut self, val: bool)

Writing a 1 to REQ1_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req2_en0(&self) -> bool

Writing a 1 to REQ2_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req2_en0(&mut self, val: bool)

Writing a 1 to REQ2_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req3_en0(&self) -> bool

Writing a 1 to REQ3_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req3_en0(&mut self, val: bool)

Writing a 1 to REQ3_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req4_en0(&self) -> bool

Writing a 1 to REQ4_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req4_en0(&mut self, val: bool)

Writing a 1 to REQ4_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req5_en0(&self) -> bool

Writing a 1 to REQ5_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req5_en0(&mut self, val: bool)

Writing a 1 to REQ5_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req6_en0(&self) -> bool

Writing a 1 to REQ6_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req6_en0(&mut self, val: bool)

Writing a 1 to REQ6_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req7_en0(&self) -> bool

Writing a 1 to REQ7_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req7_en0(&mut self, val: bool)

Writing a 1 to REQ7_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req8_en0(&self) -> bool

Writing a 1 to REQ8_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req8_en0(&mut self, val: bool)

Writing a 1 to REQ8_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req9_en0(&self) -> bool

Writing a 1 to RE9_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req9_en0(&mut self, val: bool)

Writing a 1 to RE9_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req10_en0(&self) -> bool

Writing a 1 to REQ10_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req10_en0(&mut self, val: bool)

Writing a 1 to REQ10_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req11_en0(&self) -> bool

Writing a 1 to REQ11_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req11_en0(&mut self, val: bool)

Writing a 1 to REQ11_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req12_en0(&self) -> bool

Writing a 1 to REQ12_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req12_en0(&mut self, val: bool)

Writing a 1 to REQ12_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req13_en0(&self) -> bool

Writing a 1 to REQ13_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req13_en0(&mut self, val: bool)

Writing a 1 to REQ13_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req14_en0(&self) -> bool

Writing a 1 to REQ14_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req14_en0(&mut self, val: bool)

Writing a 1 to REQ14_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req15_en0(&self) -> bool

Writing a 1 to REQ15_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req15_en0(&mut self, val: bool)

Writing a 1 to REQ15_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req16_en0(&self) -> bool

Writing a 1 to REQ16_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req16_en0(&mut self, val: bool)

Writing a 1 to REQ16_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req17_en0(&self) -> bool

Writing a 1 to REQ17_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req17_en0(&mut self, val: bool)

Writing a 1 to REQ17_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req18_en0(&self) -> bool

Writing a 1 to REQ18_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req18_en0(&mut self, val: bool)

Writing a 1 to REQ18_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req19_en0(&self) -> bool

Writing a 1 to REQ19_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req19_en0(&mut self, val: bool)

Writing a 1 to REQ19_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req20_en0(&self) -> bool

Writing a 1 to REQ20_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req20_en0(&mut self, val: bool)

Writing a 1 to REQ20_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req21_en0(&self) -> bool

Writing a 1 to REQ21_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req21_en0(&mut self, val: bool)

Writing a 1 to REQ21_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req22_en0(&self) -> bool

Writing a 1 to REQ22_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req22_en0(&mut self, val: bool)

Writing a 1 to REQ22_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req23_en0(&self) -> bool

Writing a 1 to REQ23_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req23_en0(&mut self, val: bool)

Writing a 1 to REQ23_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req24_en0(&self) -> bool

Writing a 1 to REQ24_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req24_en0(&mut self, val: bool)

Writing a 1 to REQ24_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req25_en0(&self) -> bool

Writing a 1 to REQ25_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req25_en0(&mut self, val: bool)

Writing a 1 to REQ25_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req26_en0(&self) -> bool

Writing a 1 to REQ26_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req26_en0(&mut self, val: bool)

Writing a 1 to REQ26_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req27_en0(&self) -> bool

Writing a 1 to REQ27_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req27_en0(&mut self, val: bool)

Writing a 1 to REQ27_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req28_en0(&self) -> bool

Writing a 1 to REQ28_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req28_en0(&mut self, val: bool)

Writing a 1 to REQ28_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req29_en0(&self) -> bool

Writing a 1 to REQ29_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req29_en0(&mut self, val: bool)

Writing a 1 to REQ29_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req30_en0(&self) -> bool

Writing a 1 to REQ30_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req30_en0(&mut self, val: bool)

Writing a 1 to REQ30_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn req31_en0(&self) -> bool

Writing a 1 to REQ31_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.

pub const fn set_req31_en0(&mut self, val: bool)

Writing a 1 to REQ31_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE0.