nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Dma0ReqEnable2Tog

Struct Dma0ReqEnable2Tog 

#[repr(transparent)]
pub struct Dma0ReqEnable2Tog(pub u32);
DMA0 Request Enable2

Tuple Fields

0: u32

Implementations

Source

impl Dma0ReqEnable2Tog

pub const fn req64_en0(&self) -> bool

Writing a 1 to REQ64_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req64_en0(&mut self, val: bool)

Writing a 1 to REQ64_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req65_en0(&self) -> bool

Writing a 1 to REQ65_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req65_en0(&mut self, val: bool)

Writing a 1 to REQ65_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req66_en0(&self) -> bool

Writing a 1 to REQ66_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req66_en0(&mut self, val: bool)

Writing a 1 to REQ66_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req67_en0(&self) -> bool

Writing a 1 to REQ67_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req67_en0(&mut self, val: bool)

Writing a 1 to REQ67_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req68_en0(&self) -> bool

Writing a 1 to REQ68_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req68_en0(&mut self, val: bool)

Writing a 1 to REQ68_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req69_en0(&self) -> bool

Writing a 1 to REQ69_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req69_en0(&mut self, val: bool)

Writing a 1 to REQ69_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req70_en0(&self) -> bool

Writing a 1 to REQ70_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req70_en0(&mut self, val: bool)

Writing a 1 to REQ70_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req71_en0(&self) -> bool

Writing a 1 to REQ71_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req71_en0(&mut self, val: bool)

Writing a 1 to REQ71_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req72_en0(&self) -> bool

Writing a 1 to REQ72_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req72_en0(&mut self, val: bool)

Writing a 1 to REQ72_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req73_en0(&self) -> bool

Writing a 1 to REQ73_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req73_en0(&mut self, val: bool)

Writing a 1 to REQ73_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req74_en0(&self) -> bool

Writing a 1 to REQ74_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req74_en0(&mut self, val: bool)

Writing a 1 to REQ74_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req75_en0(&self) -> bool

Writing a 1 to REQ75_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req75_en0(&mut self, val: bool)

Writing a 1 to REQ75_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req76_en0(&self) -> bool

Writing a 1 to REQ76_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req76_en0(&mut self, val: bool)

Writing a 1 to REQ76_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req77_en0(&self) -> bool

Writing a 1 to REQ77_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req77_en0(&mut self, val: bool)

Writing a 1 to REQ77_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req78_en0(&self) -> bool

Writing a 1 to REQ78_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req78_en0(&mut self, val: bool)

Writing a 1 to REQ78_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req79_en0(&self) -> bool

Writing a 1 to REQ79_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req79_en0(&mut self, val: bool)

Writing a 1 to REQ79_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req80_en0(&self) -> bool

Writing a 1 to REQ80_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req80_en0(&mut self, val: bool)

Writing a 1 to REQ80_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req81_en0(&self) -> bool

Writing a 1 to REQ81_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req81_en0(&mut self, val: bool)

Writing a 1 to REQ81_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req82_en0(&self) -> bool

Writing a 1 to REQ82_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req82_en0(&mut self, val: bool)

Writing a 1 to REQ82_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req83_en0(&self) -> bool

Writing a 1 to REQ83_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req83_en0(&mut self, val: bool)

Writing a 1 to REQ83_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req84_en0(&self) -> bool

Writing a 1 to REQ84_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req84_en0(&mut self, val: bool)

Writing a 1 to REQ84_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req85_en0(&self) -> bool

Writing a 1 to REQ85_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req85_en0(&mut self, val: bool)

Writing a 1 to REQ85_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req86_en0(&self) -> bool

Writing a 1 to REQ86_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req86_en0(&mut self, val: bool)

Writing a 1 to REQ86_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req87_en0(&self) -> bool

Writing a 1 to REQ87_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req87_en0(&mut self, val: bool)

Writing a 1 to REQ87_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req88_en0(&self) -> bool

Writing a 1 to REQ88_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req88_en0(&mut self, val: bool)

Writing a 1 to REQ88_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req91_en0(&self) -> bool

Writing a 1 to REQ91_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req91_en0(&mut self, val: bool)

Writing a 1 to REQ91_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req92_en0(&self) -> bool

Writing a 1 to REQ92_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req92_en0(&mut self, val: bool)

Writing a 1 to REQ92_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req93_en0(&self) -> bool

Writing a 1 to REQ93_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req93_en0(&mut self, val: bool)

Writing a 1 to REQ93_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req94_en0(&self) -> bool

Writing a 1 to REQ94_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req94_en0(&mut self, val: bool)

Writing a 1 to REQ94_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn req95_en0(&self) -> bool

Writing a 1 to REQ95_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.

pub const fn set_req95_en0(&mut self, val: bool)

Writing a 1 to REQ95_EN0 in this register toggles the corresponding bit in DMA0_REQ_ENABLE2.