nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Pintsel

Struct Pintsel 

#[repr(transparent)]
pub struct Pintsel(pub u32);
Pin Interrupt Select

Tuple Fields

0: u32

Implementations

Source

impl Pintsel

pub const fn inp(&self) -> PintselInp

Pin number select for pin interrupt or pattern match engine input. For PIOx_y: INP = (x * 32) + y. PIO0_0 to PIO1_31 correspond to numbers 0 to 63.

pub const fn set_inp(&mut self, val: PintselInp)

Pin number select for pin interrupt or pattern match engine input. For PIOx_y: INP = (x * 32) + y. PIO0_0 to PIO1_31 correspond to numbers 0 to 63.